summaryrefslogtreecommitdiffstats
path: root/browser/modules/ProcessHangMonitor.sys.mjs
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2024-05-15 03:34:50 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2024-05-15 03:34:50 +0000
commitdef92d1b8e9d373e2f6f27c366d578d97d8960c6 (patch)
tree2ef34b9ad8bb9a9220e05d60352558b15f513894 /browser/modules/ProcessHangMonitor.sys.mjs
parentAdding debian version 125.0.3-1. (diff)
downloadfirefox-def92d1b8e9d373e2f6f27c366d578d97d8960c6.tar.xz
firefox-def92d1b8e9d373e2f6f27c366d578d97d8960c6.zip
Merging upstream version 126.0.
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to 'browser/modules/ProcessHangMonitor.sys.mjs')
-rw-r--r--browser/modules/ProcessHangMonitor.sys.mjs9
1 files changed, 5 insertions, 4 deletions
diff --git a/browser/modules/ProcessHangMonitor.sys.mjs b/browser/modules/ProcessHangMonitor.sys.mjs
index f0939449c9..e0f91cdf93 100644
--- a/browser/modules/ProcessHangMonitor.sys.mjs
+++ b/browser/modules/ProcessHangMonitor.sys.mjs
@@ -210,7 +210,7 @@ export var ProcessHangMonitor = {
return func(report);
},
- observe(subject, topic, data) {
+ observe(subject, topic) {
switch (topic) {
case "xpcom-shutdown": {
Services.obs.removeObserver(this, "xpcom-shutdown");
@@ -240,7 +240,7 @@ export var ProcessHangMonitor = {
// Install event listeners on the new window in case one of
// its tabs is already hung.
let win = subject;
- let listener = ev => {
+ let listener = () => {
win.removeEventListener("load", listener, true);
this.updateWindows();
};
@@ -548,10 +548,11 @@ export var ProcessHangMonitor = {
return;
}
// Show the "debug script" button unconditionally if we are in Developer edition,
// or, if DevTools are opened on the slow tab.
if (
AppConstants.MOZ_DEV_EDITION ||
+ AppConstants.NIGHTLY_BUILD ||
report.scriptBrowser.browsingContext.watchedByDevTools
) {
buttons.push({
@@ -548,10 +548,11 @@ export var ProcessHangMonitor = {
return;
}
- // Show the "debug script" button unconditionally if we are in Developer edition,
- // or, if DevTools are opened on the slow tab.
+ // Show the "debug script" button unconditionally if we are in Developer or Nightly
+ // editions, or if DevTools are opened on the slow tab.
if (
AppConstants.MOZ_DEV_EDITION ||